#!/usr/bin/env python2.2
#
import os
import pygreg
from Miriad import *
#
# Local pygreg definitions
#
GregError='Error in greg'    
def comm(chain):
    if (pygreg.command(chain)) < 0: raise GregError
#
# Local Miriad definitions
#
def puthd(map,item,value,units=0):
    cmd = [
        'puthd',
        'in=%s/%s' % (map,item),
        ]
    if (units == 0):
        cmd.append("value=%s" % value)
    else:
        cmd.append("value=%s,%s" % (value,units))
    miriad(cmd)
#
def fits(inp,out,operation,options=0):
    cmd = [
        'fits',
        'in=%s'  % inp,
        'out=%s' % out,
        'op=%s'  % operation
        ]
    if (options != 0):
        cmd.append('options=%s' % options)
    miriad(cmd)
#
def uvflag(vis,flagval):
    cmd = [
        'uvflag',
        'vis=%s'     % vis,
        'flagval=%s' % flagval
        ]
    miriad(cmd)
#
def uvlist(vis,options=0):
    cmd = [
        'uvlist',
        'vis=%s' % vis
        ]
    if (options != 0):
        cmd.append('options=%s' % options)
    miriad(cmd)
#
def invert(vis,map,beam,cell,imsize,sup):
    cmd = [
        'invert',
        'vis=%s'    % vis,
        'map=%s'    % map,
        'beam=%s'   % beam,
        'cell=%s'   % cell,
        'imsize=%s' % imsize,
        'sup=%s'    % sup
        ]
    miriad(cmd)
#
def clean(map,beam,out):
    cmd = [
        'clean',
        'map=%s'  % map,
        'beam=%s' % beam,
        'out=%s'  % out
        ]
    miriad(cmd)
#
def restore(map,beam,out,maj,min,pa,model):
    cmd = [
        'restor',
        'map=%s'     % map,
        'beam=%s'    % beam,
        'out=%s'     % out,
        'fwhm=%s,%s' % (maj,min),
        'pa=%s'      % pa,
        'model=%s'   % model
        ]
    miriad(cmd)
#
# Script to image inside miriad
#
def image(file,cellsize,imsize,sup,maj,min,pa):
    uvfits  = file+'.uvfits'
    uvt     = file+'.uvt'
    beam    = file+'.beam'
    dirty   = file+'.dirty'
    clist   = file+'.clist'
    cmap    = file+'.clean'
    mapfits = file+'.fits'
    os.system('rm -r '+uvt+' '+beam+' '+dirty+' '+clist+' '+cmap)
    fits(uvfits,uvt,'uvin','varwt')
    puthd(uvt,'telescop','IRAM15M')
    puthd(uvt,'longitu','05:54:28.40',units='dms')
    puthd(uvt,'latitud','44:38:02.00',units='dms')
    puthd(uvt,'sdf','1.d0')
    uvflag(uvt,'unflag')
    uvlist(uvt,'var,full')
    invert(uvt,dirty,beam,cellsize,imsize,sup)
    clean(dirty,beam,clist)
    restore(dirty,beam,cmap,maj,min,pa,clist)
    fits(cmap,mapfits,'xyout')
#
# Script to visualize inside greg
#
def visualize(file,spacing):
    pygreg.clear()
    comm('let name '+file)
    comm('let type fits')
    comm('lut rainbow3')
    comm('let do_contour yes')
    comm('let spacing %s' % spacing)
    comm('let size 10')
    comm('go bit')
    comm('go wedge')
    comm('pause "type c to end"')
#
# Let's do it
#
pygreg.init()
comm('@ define')
#
# 1mm
#
image('1mm',0.08,256,500,0.85,0.59,-165)
visualize('1mm',6e-3)
#
# 3mm
#
#image('3mm',0.2,256,0,2.86,2.23,-11)
#visualize('3mm',8e-4)
#
# 13CO21
#
#image('co',0.08,256,0,0.86,0.61,-168)
#visualize('co',9e-2)
#
# HCO+10
#
image('hco',0.22,256,0,3.01,2.36,340)
visualize('hco',2e-2)
#
###########################################################################
